
## Today

- 最近修改列表（无法激活菜单时更新）
- 兼容py34

V 交换位置复制(Ctrl+Shift+X)
V 插入时间戳注释
V 增加模块导入入口

## editor

V 快速输入call tips内容
- 自动保存untitled的内容
- 内建搜索窗口不置顶


## shell

V 多行运行
V 清空shell
X 历史记录到文本
X 自由编辑模式（F12）
- 取消换行


# TODO 交换文件名

# TODO 删除shell一行
